import {languageServer, LanguageServerClient} from 'codemirror-languageserver';
import {WebSocketTransport} from "@open-rpc/client-js";
import {EditorState} from "@codemirror/state";
import {EditorView, lineNumbers} from "@codemirror/view";
import { spawn } from 'child_process';

// Spawn the language server process.
const childProcess = spawn('java', ['-jar', 'language-server-all.jar']);
// Create a new WebSocket client.
const ws = new WebSocket('ws://localhost:8080');
// Redirect the child process's stdout to the WebSocket client.
childProcess.stdout.pipe(ws);

// Redirect the WebSocket client's incoming messages to the child process's stdin.
ws.on('message', (data) => {
    childProcess.stdin.write(data);
});

// Open the WebSocket client.
ws.open();

// Create a new language server client.
const ls = languageServer({
    // The WebSocket server uri and other client options.
    serverUri: 'ws://localhost:8080',
    transport: new WebSocketTransport(ws),
    documentUri: `file:///${filename}`,
    languageId: 'groovy',
});

const view = new EditorView({
    state: EditorState.create({
        extensions: [
            lineNumbers(),
            ls
        ],
    }),
});
